<?php

namespace Ems\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;


use Ems\Services\VinculoService;

class VinculoController {
    /** @var VinculoService */
    protected $vinculoService;

    public function __construct(
        VinculoService $vinculoService
    ) {
        $this->vinculoService = $vinculoService;
    }

    public function getVinculoTodos(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $dtMesCompetencia = $row['DTMESCOMPETENC'] ?? null;

            $vinculos = $this->vinculoService->getVinculoTodos(
                $dtMesCompetencia
            );

            $response->addDataSet(new DataSet('getVinculoTodos', $vinculos));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getVinculoTodosResp(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();

            $cdOperador = (string) $row['CDOPERADOR'];

            /** @var string */
            $dtMesCompetencia = $row['DTMESCOMPETENC'] ?? null;

            $vinculos = $this->vinculoService->getVinculoTodosResp(
                $cdOperador, $dtMesCompetencia
            );

            $response->addDataSet(new DataSet('getVinculoTodosResp', $vinculos));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
    
    public function getHorarioBaseDia(
        Request\Row $request,
        Response $response    
    ) {
        try {
            $row = $request->getRow();

            $nrVinculo  = (string) $row['NRVINCULOM'];
            $date       = (string) $row['DATE'];

            $horarioBase = $this->vinculoService->getHorarioBase(
                $nrVinculo, $date
            );

            $response->addDataSet(new DataSet('getHorarioBaseDia', $horarioBase));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
