<?php

namespace Ems\Logic\Offline;

class OfflineAbsence extends OfflineEntity {
    
    /* @var string */
    private $nrVinculo;
    /* @var string */
    private $date;
    /* @var int */
    private $nrMarcacao;
    /* @var string */
    private $type;
    /* @var string */
    private $motive;
    /* @var string */
    private $observation;
    /* @var string */
    private $attachmentFile;
    /* @var string */
    private $attachmentName;
    /* @var bool */
    private $isLunchBreak;
    
    private const DEFAULT_WEEK_DAY = '1111111';
    
    private function __construct(?string $nrVinculo, ?string $date, ?int $nrMarcacao, ?string $type, ?string $motive, ?string $observation, ?string $attachmentFile, ?string $attachmentName, ?bool $isLunchBreak) {
        $this->nrVinculo = $nrVinculo;
        $this->date = $date;
        $this->nrMarcacao = $nrMarcacao;
        $this->type = $type;
        $this->motive = $motive;
        $this->observation = $observation;
        $this->attachmentFile = $attachmentFile;
        $this->attachmentName = $attachmentName;
        $this->isLunchBreak = $isLunchBreak;
    }
    
    public static function fromArray(?array $row) {
        return new OfflineAbsence(
            $row['nrVinculo'] ?? null,
            $row['date'] ?? null,
            $row['nrMarcacao'] ?? null,
            $row['type'] ?? null,
            $row['motive'] ?? null,
            $row['observation'] ?? null,
            $row['attachmentFile'] ?? null,
            $row['attachmentName'] ?? null,
            $row['isLunchBreak'] ?? null
        );
    }
    
    public function synchronize(): void {
        $this->setAbsence();
    }
    
    private function setAbsence(): void {
        if ($this->isLunchBreak) {
            $this->setLunchAbsence();
            return;
        }
        
        $this->setDefaultAbsence();
    }
    
    private function setDefaultAbsence(): void {
        $newAbsence = [
            'NRTIPOPROGOCORRENCIA'  => $this->type,
            'NRMOTIVOOCORFREQ'      => $this->motive,
            'NRVINCULOM'            => $this->nrVinculo,
            'NRMARCACAOPONTO'       => $this->nrMarcacao,
            'DTINICIOPROGOCOR'      => $this->date,
            'DTFIMPROGOCOR'         => $this->date,
            'NRORG'                 => $this->getNrorg(),
            'IDDIASSEMANA'          => self::DEFAULT_WEEK_DAY,
            'DSOBSERVACAO'          => $this->observation,
            'FILE'                  => $this->attachmentFile,
            'NMFILE'                => $this->attachmentName,
            '__is_new'              => true,
        ];
            
        $this->getOcorrenciaServiceInstance()->setOcorrenciaFreq($newAbsence);
    }
    
    private function setLunchAbsence(): void {
        $this->getOcorrenciaServiceInstance()->setOcorrenciaAlmoco(
            $this->nrVinculo,
            $this->getNrorg(),
            $this->nrMarcacao,
            $this->getCdoperador(),
            $this->date
        );
    }
}